import React, { useEffect } from 'react';
import Paper from '@material-ui/core/Paper';
import styled from 'styled-components';
import Grid from '@material-ui/core/Grid';
import LoadingSpinner from '../LoadingSpinner';
import ContactCard from '../ContactCard';
import IconButton from '@material-ui/core/IconButton';
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import ArrowForwardIcon from '@material-ui/icons/ArrowForward';
import { apiDomain } from '../../env';

export default function ResourceTemplate({ isLoading, resources, totalResources, currPage, handlePreviousPage, handleNextPage }) {
  const totalPages = parseInt(totalResources) === 0 ? 0 : Math.ceil(totalResources / 12) - 1; //Dividing by 12 because i want to cath total pages, and results per page is 12
  const topRef = React.useRef();

  useEffect(() => {
    topRef.current.scrollIntoView()
  }, [isLoading])

  return (
    <ResourcePaper elevation={4} square>
      <div ref={topRef} />
      <Title>
        Usuários encontrados ({totalResources})
      </Title>
      {
        isLoading ?
          <LoadingSpinner text='Carregando recursos...' />
          :
          <Grid container justify='center' alignItems='center' spacing={3}>
            {
              resources.length >= 1 ?
                resources.map((card) => {
                  return <Grid item key={new Date().toISOString() + card.id} >
                    <ContactCard
                      name={card.name}
                      avatar={card.avatar ? apiDomain + card.avatar : null}
                      cover={card.cover ? apiDomain + card.cover : null}
                      numCollections={card.collections_count}
                      numLearningObjects={card.learning_objects_count}
                      follow_count={card.follows_count}
                      followed={card.followed || null}
                      followerID={card.id}
                      href={'/usuario-publico/' + card.id}
                    />
                  </Grid>
                })
                :
                <NoContentDiv>
                  <h3>
                    Desculpe, não há dados nessa página.
                  </h3>
                </NoContentDiv>
            }
          </Grid>
      }
      {
        !isLoading &&
        <Grid container direction='row' alignItems='center' justify='center' spacing={3}>
          <Grid item>
            <StyledIconButton elevation={4} disabled={currPage === 0}>
              <IconButton onClick={handlePreviousPage} disabled={currPage === 0}>
                <ArrowBackIcon className='icon' />
              </IconButton>
            </StyledIconButton>
          </Grid>
          <Grid item>
            <ActualPage>
              {currPage}
            </ActualPage>...{totalPages}
          </Grid>
          <Grid item>
            <StyledIconButton elevation={4} disabled={currPage === totalPages}>
              <IconButton onClick={handleNextPage} disabled={currPage === totalPages}>
                <ArrowForwardIcon className='icon' />
              </IconButton>
            </StyledIconButton>
          </Grid>
        </Grid>
      }
    </ResourcePaper>
  )
};

const Title = styled.h4`
  text-transform: uppercase;
  font-weight: 500;
  text-align: left; 
  color: #00bcd4;
`
const NoContentDiv = styled.div`
  >h3{
    color: #00bcd4;
    text-align: center;
  }
`
const ActualPage = styled.span`
  color: #00bcd4;
`
const StyledIconButton = styled(Paper)` 
  border-radius: 50% !important;
  background-color: ${props => props.disabled ? "#666" : "#00bcd4"} !important;
  .icon{
    color: ${props => props.disabled ? "#d4d4d4" : "white"};
  }
`

const ResourcePaper = styled(Paper)`
  /* height: 150px; */
  text-align: center;
  background-color: #fff;
  margin-top: 5px;
  margin-bottom: 30px;
  padding: 0.5em 1em;
  color: #666;
  .textInfo{
    text-align: start;
  }
`;