/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import LoadingSpinner from '../../LoadingSpinner.js'
import Template from '../PanelComponents/TemplateRecurso.js'
import PanelTemplateColecao from '../PanelComponents/TemplateColecao.js'
import { fetchAllRequest, getRequest } from '../../HelperFunctions/getAxiosConfig'

export default function TabPanelFavoritos(props) {
    const [loading, handleLoading] = useState(true)

    const [errorInLikedInLearnObj, setErrorInLikedInLearnObj] = useState(false)
    const [errorInLikedInColl, setErrorInLikedInColl] = useState(false)

    const [likedLearnObjs, setlikedLearnObjs] = useState([])
    const [likedCollections, setlikedCollections] = useState([])
    const [currLimitLearnObjLiked, setCurrLimitLearnObjLiked] = useState(4);
    const [currLimitCollLiked, setcurrLimitCollLiked] = useState(4);

    const [loadingMoreLearnObj, setLoadingMoreLearnObj] = useState(false)
    const [loadingMoreColl, setLoadingMoreColl] = useState(false)

    const [endOfLearnObj, setEndofLearndObj] = useState(0)
    const [endOfColl, setEndoffColl] = useState(0)


    function handleSuccess(responseArr, headersArr) {
        setErrorInLikedInLearnObj(responseArr[0].errors ? true : false)
        setErrorInLikedInColl(responseArr[1].errors ? true : false)

        setlikedLearnObjs(responseArr[0])
        setlikedCollections(responseArr[1])

        if (headersArr[0].has('X-Total-Count')) {
            setEndofLearndObj(headersArr[0].get('X-Total-Count'));
        }
        if (headersArr[1].has('X-Total-Count')) {
            setEndoffColl(headersArr[1].get('X-Total-Count'));
        }
        handleLoading(false)
    }

    function handleError(error) {
        handleLoading(false)
        setErrorInLikedInLearnObj(true)
        setErrorInLikedInColl(true)
    }

    useEffect(() => {
        handleLoading(true);
        const urls = [
            `/users/${props.id}/learning_objects/liked?offset=0&limit=4`,
            `/users/${props.id}/collections/liked?offset=0&limit=4`
        ]

        fetchAllRequest(urls, handleSuccess, handleError)

    }, [])

    const showMoreLikedLearnObj = (limite) => {
        setLoadingMoreLearnObj(true);
        const limit = limite;
        setCurrLimitLearnObjLiked(currLimitLearnObjLiked + limit)
        const url = `/users/${props.id}/learning_objects/liked?offset=${currLimitLearnObjLiked}&limit=${limit}`;
        getRequest(url,
            (data) => {
                if (data.errors) {
                    setLoadingMoreLearnObj(false);
                    setErrorInLikedInLearnObj(true);
                }
                else if (data.length >= 1) {
                    let currData = [...likedLearnObjs];
                    currData = [...currData.concat(data)];
                    setLoadingMoreLearnObj(false);
                    setlikedLearnObjs(currData);
                }
                else {
                    setLoadingMoreLearnObj(false);
                }
            },
            (error) => {
                setLoadingMoreLearnObj(false);
                setErrorInLikedInLearnObj(true);
            }
        )
    }

    const showMoreLikedCollections = (limite) => {
        const limit = limite;
        setLoadingMoreColl(true);
        setcurrLimitCollLiked(currLimitCollLiked + limit);
        const url = `/users/${props.id}/collections/liked?offset=${currLimitCollLiked}&limit=${limit}`;
        getRequest(url,
            (data) => {
                if (data.errors) {
                    setLoadingMoreColl(false);
                    setErrorInLikedInColl(true)
                }
                if (data.length >= 1) {
                    let currData = [...likedCollections];
                    currData = [...currData.concat(data)];
                    setLoadingMoreColl(false);
                    setlikedCollections(currData);
                }
                else {
                    setLoadingMoreColl(false);
                }
            },
            (error) => {
                setLoadingMoreColl(false);
                setErrorInLikedInColl(true)
            }
        )
    }

    return (
        <>
            {
                loading ?
                    (
                        <LoadingSpinner contrast={props.contrast} text={'CARREGANDO...'} />
                    )
                    :
                    (
                        [
                            <React.Fragment>
                                <Template
                                    contrast={props.contrast}
                                    length={likedLearnObjs.length}
                                    titleText={likedLearnObjs.length === 1 ? "Recurso favoritado" : "Recursos favoritados"}
                                    noContentText={"Você não favoritou nenhum recurso ainda"}
                                    slice={likedLearnObjs}
                                    showMore={showMoreLikedLearnObj}
                                    loadingMore={loadingMoreLearnObj}
                                    end={endOfLearnObj}
                                    error={errorInLikedInLearnObj}
                                />

                                <PanelTemplateColecao
                                    contrast={props.contrast}
                                    title={"Coleções favoritadas"}
                                    length={likedCollections.length}
                                    noContentText={"Você ainda não curtiu nenhuma coleção."}
                                    sliceArr={likedCollections}
                                    showMore={showMoreLikedCollections}
                                    loadingMore={loadingMoreColl}
                                    end={endOfColl}
                                    followed={false}
                                    error={errorInLikedInColl}
                                />
                            </React.Fragment>
                        ]
                    )
            }
        </>
    )
}
